"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const path = require("path");
require("chai");
describe('read', () => {
    describe('output', () => {
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.yml')])
            .it('reads yaml openapi spec', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('My API');
        });
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.json')])
            .it('reads json openapi spec', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('My API');
        });
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.json'), '--server', 'http://localhost:9999'])
            .it('can add a server', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('http://localhost:9999');
        });
        test_1.test
            .stdout()
            .command([
            'read',
            path.join('examples', 'openapi.json'),
            '-S',
            'http://localhost:9998',
            '-S',
            'http://localhost:9999',
        ])
            .it('can add multiple servers', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('http://localhost:9998');
            test_1.expect(ctx.stdout).to.contain('http://localhost:9999');
        });
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.yml'), '--json'])
            .it('reads openapi spec and outputs json', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('My API');
            test_1.expect(ctx.stdout).to.contain('{');
            test_1.expect(ctx.stdout).to.contain('"openapi": "3');
            test_1.expect(ctx.stdout).to.contain('}');
        });
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.yml'), '--yaml'])
            .it('reads openapi spec and outputs yaml', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('My API');
            test_1.expect(ctx.stdout).to.contain('openapi: 3');
        });
    });
    describe('validation', () => {
        test_1.test
            .stdout()
            .command(['read', path.join('examples', 'openapi.yml'), '--validate'])
            .it('validates correct openapi spec and outputs', (ctx) => {
            test_1.expect(ctx.stdout).to.contain('My API');
        });
        test_1.test
            .command(['read', path.join('examples', 'openapi-broken.yml'), '--validate'])
            .exit(1)
            .it('validates incorrect openapi spec, exits with code 1');
    });
});
